@@ -1,14 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from collections import Counter
 import sys
-import warnings
-try:
-    # Surpress warnings of traitlets
-    warnings.filterwarnings("ignore", category=SyntaxWarning)
-except Exception:
-    pass
 try:
     import better_exceptions
     better_exceptions_installed = True
@@ -18,10 +11,11 @@ from covsirphy.__version__ import __version__
 from covsirphy.cleaning import Term, CleaningBase, DataLoader
 from covsirphy.cleaning import JHUData, CountryData, PopulationData, OxCGRTData
 from covsirphy.ode import ModelBase, SIR, SIRD, SIRF, SIRFV, SEWIRF
-from covsirphy.phase import Trend, ChangeFinder, PhaseSeries
+from covsirphy.phase import Trend, ChangeFinder, PhaseSeries, PhaseUnit, MPEstimator
 from covsirphy.simulation import Optimizer, ODESimulator, Estimator
-from covsirphy.util import line_plot, jpn_map, StopWatch, error
+from covsirphy.util import line_plot, jpn_map, StopWatch, error, find_args
 from covsirphy.analysis import ExampleData, Scenario
+from covsirphy.worldwide import PolicyMeasures
 # Deprecated
 from covsirphy.cleaning import Population, Word
 
@@ -35,22 +29,17 @@ def get_version():
 
 __all__ = [
     "ODESimulator", "ChangeFinder",
-    "PhaseSeries", "Scenario", "ExampleData",
+    "PhaseSeries", "Scenario", "ExampleData", "PhaseUnit", "MPEstimator",
     "Term", "CleaningBase", "DataLoader",
     "JHUData", "CountryData", "PopulationData", "OxCGRTData",
     "ModelBase", "SIR", "SIRD", "SIRF", "SIRFV", "SEWIRF",
     "Estimator", "Trend", "Optimizer",
-    "line_plot", "jpn_map", "StopWatch", "error",
+    "line_plot", "jpn_map", "StopWatch", "error", "find_args",
+    "PolicyMeasures",
     # Deprecated
     "Population", "Word",
 ]
 
-# Check duplication
-dup_list = [k for (k, v) in Counter(__all__).items() if v > 1]
-if dup_list:
-    dup_str = ', '.join(dup_list)
-    raise Exception(f"Duplication was found in modules. {dup_str}")
-
 # Show exceptions in better format if used from command line
 if not hasattr(sys, "ps1") or not better_exceptions_installed:
     better_exceptions.MAX_LENGTH = None
