@@ -57,8 +57,7 @@ class CleaningBase(Term):
         Returns:
             (pandas.DataFrame): cleaned data
         """
-        df = self._raw.copy()
-        return df
+        return self._raw.copy()
 
     @property
     def citation(self):
@@ -69,16 +68,14 @@ class CleaningBase(Term):
 
     @citation.setter
     def citation(self, description):
-        if not isinstance(description, str):
-            raise TypeError("@description must be a string.")
-        self._citation = description
+        self._citation = str(description)
 
     def iso3_to_country(self, iso3_code):
         """
         Convert ISO3 code to country name if records are available.
 
         Args:
-            iso3_code (str): ISO3 code
+            iso3_code (str): ISO3 code or country name
 
         Returns:
             (str): country name
@@ -153,10 +150,7 @@ class CleaningBase(Term):
             return df
         df = df.loc[df[self.COUNTRY] == country, :]
         df = df.drop(self.COUNTRY, axis=1)
-        try:
-            df = df.drop(self.ISO3, axis=1)
-        except KeyError:
-            pass
+        df = df.drop(self.ISO3, axis=1, errors="ignore")
         return df.reset_index(drop=True)
 
     def _subset_by_province(self, record_df, province):
@@ -277,13 +271,13 @@ class CleaningBase(Term):
         df = self._subset_by_area(country=country, province=province)
         # Subset with Start/end date
         if start_date is None and end_date is None:
-            return df
+            return df.reset_index(drop=True)
         if self.DATE not in df.columns:
             raise KeyError(
                 "@start_date or @end_date was specified, but the dataset does not have Date column.")
         series = df[self.DATE].copy()
-        start_obj = self.to_date_obj(date_str=start_date, default=series.min())
-        end_obj = self.to_date_obj(date_str=end_date, default=series.max())
+        start_obj = self.date_obj(date_str=start_date, default=series.min())
+        end_obj = self.date_obj(date_str=end_date, default=series.max())
         df = df.loc[(start_obj <= series) & (series <= end_obj), :]
         df = df.reset_index(drop=True)
         if df.empty:
@@ -305,8 +299,7 @@ class CleaningBase(Term):
         df = self._cleaned_df.copy()
         if self.COUNTRY not in df.columns:
             raise KeyError("Country names are not registered in this dataset.")
-        country_list = list(df[self.COUNTRY].unique())
-        return country_list
+        return list(df[self.COUNTRY].unique())
 
     def total(self):
         """
