@@ -2,13 +2,15 @@
 # -*- coding: utf-8 -*-
 
 import numpy as np
-from covsirphy.ode.mbasecom import ModelBaseCommon
+from covsirphy.cleaning.term import Term
 
 
-class ModelBase(ModelBaseCommon):
+class ModelBase(Term):
     """
     Base class of ODE models.
     """
+    # Quartile range of the parametes when setting initial values
+    QUANTILE_RANGE = [0.3, 0.7]
     # Model name
     NAME = "ModelBase"
     # names of parameters
@@ -40,7 +42,23 @@ class ModelBase(ModelBaseCommon):
         self.population = self.ensure_natural_int(
             population, name="population"
         )
-        # Non-dim parameters
+        # Dictionary of non-dim parameters: {name: value}
+        self.non_param_dict = {}
+
+    def __str__(self):
+        param_str = ", ".join(
+            [f"{p}={v}" for (p, v) in self.non_param_dict.items()]
+        )
+        return f"{self.NAME} model with {param_str}"
+
+    def __getitem__(self, key):
+        """
+        Args:
+            key (str): parameter name
+        """
+        if key not in self.non_param_dict.keys():
+            raise KeyError(f"key must be in {', '.join(self.PARAMETERS)}")
+        return self.non_param_dict[key]
 
     def __call__(self, t, X):
         """
@@ -48,9 +66,9 @@ class ModelBase(ModelBaseCommon):
         This method should be overwritten in subclass.
 
         Returns:
-            (np.array)
+            np.array
         """
-        return np.array(list())
+        raise NotImplementedError
 
     @classmethod
     def param_range(cls, taufree_df, population):
@@ -72,8 +90,7 @@ class ModelBase(ModelBaseCommon):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        _dict = dict()
-        return _dict
+        raise NotImplementedError
 
     @classmethod
     def specialize(cls, data_df, population):
@@ -101,10 +118,7 @@ class ModelBase(ModelBaseCommon):
                     - any columns @data_df has
                     - columns with dimensional variables
         """
-        df = cls.ensure_dataframe(
-            data_df, name="data_df", columns=cls.VALUE_COLUMNS
-        )
-        return df
+        raise NotImplementedError
 
     @classmethod
     def restore(cls, specialized_df):
@@ -144,8 +158,11 @@ class ModelBase(ModelBaseCommon):
         """
         Calculate (basic) reproduction number.
         This method should be overwritten in subclass.
+
+        Returns:
+            float
         """
-        return None
+        raise NotImplementedError
 
     def calc_days_dict(self, tau):
         """
@@ -154,8 +171,11 @@ class ModelBase(ModelBaseCommon):
 
         Args:
             param tau (int): tau value [min]
+
+        Returns:
+            dict[str, int]
         """
-        return dict()
+        raise NotImplementedError
 
     @classmethod
     def tau_free(cls, subset_df, population, tau=None):
@@ -187,18 +207,16 @@ class ModelBase(ModelBaseCommon):
                     - columns with dimensional variables
         """
         df = subset_df.copy()
-        if tau is not None:
-            tau = cls.ensure_natural_int(tau, name="tau")
-            if tau > 1440:
-                raise ValueError(
-                    f"@tau must be 1440 or lower, but {tau} was applied.")
-            df = cls.ensure_dataframe(
-                df, name="data_df", columns=cls.NLOC_COLUMNS)
-            # Calculate elapsed time from the first date [min]
-            df[cls.T] = (df[cls.DATE] - df[cls.DATE].min()).dt.total_seconds()
-            df[cls.T] = df[cls.T] // 60
-            # Convert to tau-free
-            df[cls.TS] = (df[cls.T] / tau).astype(np.int64)
-            df = df.drop(cls.T, axis=1)
-        df = df.drop(cls.DATE, axis=1)
-        return cls.specialize(df, population)
+        if tau is None:
+            df = df.drop(cls.DATE, axis=1)
+            return cls.specialize(df, population=population).reset_index(drop=True)
+        tau = cls.ensure_tau(tau)
+        df = cls.ensure_dataframe(
+            df, name="data_df", columns=cls.NLOC_COLUMNS)
+        # Calculate elapsed time from the first date [min]
+        df[cls.T] = (df[cls.DATE] - df[cls.DATE].min()).dt.total_seconds()
+        df[cls.T] = df[cls.T] // 60
+        # Convert to tau-free
+        df[cls.TS] = (df[cls.T] / tau).astype(np.int64)
+        df = df.drop([cls.T, cls.DATE], axis=1)
+        return cls.specialize(df, population).reset_index(drop=True)
