@@ -50,6 +50,7 @@ class SIR(ModelBase):
         # Non-dim parameters
         self.rho = rho
         self.sigma = sigma
+        self.non_param_dict = {"rho": rho, "sigma": sigma}
 
     def __call__(self, t, X):
         """
@@ -129,7 +130,8 @@ class SIR(ModelBase):
                         - Susceptible (int): the number of susceptible cases
                         - Fatal or Recovered (int): total number of fatal/recovered cases
         """
-        df = super().specialize(data_df, population)
+        df = cls.ensure_dataframe(
+            data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = population - df[cls.C]
         df[cls.FR] = df[cls.F] + df[cls.R]
@@ -173,8 +175,14 @@ class SIR(ModelBase):
     def calc_r0(self):
         """
         Calculate (basic) reproduction number.
+
+        Returns:
+            float
         """
-        rt = self.rho / self.sigma
+        try:
+            rt = self.rho / self.sigma
+        except ZeroDivisionError:
+            return None
         return round(rt, 2)
 
     def calc_days_dict(self, tau):
@@ -183,9 +191,14 @@ class SIR(ModelBase):
 
         Args:
             param tau (int): tau value [min]
+
+        Returns:
+            dict[str, int]
         """
-        _dict = {
-            "1/beta [day]": int(tau / 24 / 60 / self.rho),
-            "1/gamma [day]": int(tau / 24 / 60 / self.sigma)
-        }
-        return _dict
+        try:
+            return {
+                "1/beta [day]": int(tau / 24 / 60 / self.rho),
+                "1/gamma [day]": int(tau / 24 / 60 / self.sigma)
+            }
+        except ZeroDivisionError:
+            return {p: None for p in self.DAY_PARAMETERS}
