@@ -57,6 +57,8 @@ class SIRF(ModelBase):
         self.kappa = kappa
         self.rho = rho
         self.sigma = sigma
+        self.non_param_dict = {
+            "theta": theta, "kappa": kappa, "rho": rho, "sigma": sigma}
 
     def __call__(self, t, X):
         """
@@ -139,7 +141,8 @@ class SIRF(ModelBase):
                     - any columns @data_df has
                     - Susceptible (int): the number of susceptible cases
         """
-        df = super().specialize(data_df, population)
+        df = cls.ensure_dataframe(
+            data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = population - df[cls.C]
         return df
@@ -181,8 +184,14 @@ class SIRF(ModelBase):
     def calc_r0(self):
         """
         Calculate (basic) reproduction number.
+
+        Returns:
+            float
         """
-        rt = self.rho * (1 - self.theta) / (self.sigma + self.kappa)
+        try:
+            rt = self.rho * (1 - self.theta) / (self.sigma + self.kappa)
+        except ZeroDivisionError:
+            return None
         return round(rt, 2)
 
     def calc_days_dict(self, tau):
@@ -191,11 +200,16 @@ class SIRF(ModelBase):
 
         Args:
             param tau (int): tau value [min]
+
+        Returns:
+            dict[str, int]
         """
-        _dict = {
-            "alpha1 [-]": round(self.theta, 3),
-            "1/alpha2 [day]": int(tau / 24 / 60 / self.kappa),
-            "1/beta [day]": int(tau / 24 / 60 / self.rho),
-            "1/gamma [day]": int(tau / 24 / 60 / self.sigma)
-        }
-        return _dict
+        try:
+            return {
+                "alpha1 [-]": round(self.theta, 3),
+                "1/alpha2 [day]": int(tau / 24 / 60 / self.kappa),
+                "1/beta [day]": int(tau / 24 / 60 / self.rho),
+                "1/gamma [day]": int(tau / 24 / 60 / self.sigma)
+            }
+        except ZeroDivisionError:
+            return {p: None for p in self.DAY_PARAMETERS}
