@@ -22,7 +22,7 @@ class SIRFV(ModelBase):
     # names of parameters
     PARAMETERS = ["theta", "kappa", "rho", "sigma", "omega"]
     DAY_PARAMETERS = [
-        "alpha1", "1/alpha2 [day]", "1/beta [day]", "1/gamma [day]",
+        "alpha1 [-]", "1/alpha2 [day]", "1/beta [day]", "1/gamma [day]",
         "Vaccinated [persons]"
     ]
     # Variable names in (non-dim, dimensional) ODEs
@@ -72,6 +72,8 @@ class SIRFV(ModelBase):
                 raise ValueError(
                     "@v_per_day / @population does not match @omega.")
         self.omega = omega
+        self.non_param_dict = {
+            "theta": theta, "kappa": kappa, "rho": rho, "sigma": sigma, "omega": omega}
 
     def __call__(self, t, X):
         """
@@ -87,8 +89,8 @@ class SIRFV(ModelBase):
         n = self.population
         s, i, *_ = X
         beta_si = self.rho * s * i / n
-        dvdt = self.omega * n
-        dsdt = 0 - beta_si - dvdt
+        dsdt = max(0 - beta_si - self.omega * n, - s)
+        dvdt = 0 - dsdt - beta_si
         drdt = self.sigma * i
         dfdt = self.kappa * i + (0 - beta_si) * self.theta
         didt = 0 - dsdt - drdt - dfdt - dvdt
@@ -154,7 +156,8 @@ class SIRFV(ModelBase):
                     - Susceptible (int): 0
                     - Vactinated (int): 0
         """
-        df = super().specialize(data_df, population)
+        df = cls.ensure_dataframe(
+            data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = 0
         df[cls.V] = 0
@@ -198,8 +201,14 @@ class SIRFV(ModelBase):
     def calc_r0(self):
         """
         Calculate (basic) reproduction number.
+
+        Returns:
+            float
         """
-        rt = self.rho * (1 - self.theta) / (self.sigma + self.kappa)
+        try:
+            rt = self.rho * (1 - self.theta) / (self.sigma + self.kappa)
+        except ZeroDivisionError:
+            return None
         return round(rt, 2)
 
     def calc_days_dict(self, tau):
@@ -208,12 +217,17 @@ class SIRFV(ModelBase):
 
         Args:
             param tau (int): tau value [min]
+
+        Returns:
+            dict[str, int]
         """
-        _dict = {
-            "alpha1": round(self.theta, 3),
-            "1/alpha2 [day]": int(tau / 24 / 60 / self.kappa),
-            "1/beta [day]": int(tau / 24 / 60 / self.rho),
-            "1/gamma [day]": int(tau / 24 / 60 / self.sigma),
-            "Vaccinated [persons]": int(self.omega * self.population)
-        }
-        return _dict
+        try:
+            return {
+                "alpha1 [-]": round(self.theta, 3),
+                "1/alpha2 [day]": int(tau / 24 / 60 / self.kappa),
+                "1/beta [day]": int(tau / 24 / 60 / self.rho),
+                "1/gamma [day]": int(tau / 24 / 60 / self.sigma),
+                "Vaccinated [persons/day]": int(self.omega * self.population)
+            }
+        except ZeroDivisionError:
+            return {p: None for p in self.DAY_PARAMETERS}
