@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 
 import math
-import warnings
 import numpy as np
 import optuna
 import pandas as pd
+from covsirphy.util.argument import find_args
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.util.stopwatch import StopWatch
 from covsirphy.ode.mbase import ModelBase
@@ -18,55 +18,50 @@ class Estimator(Optimizer):
     Hyperparameter optimization of an ODE model.
 
     Args:
-        jhu_data (covsirphy.JHUData): object of records
+        record_df (pandas.DataFrame)
+            Index:
+                reset index
+            Columns:
+                - Date (pd.TimeStamp): Observation date
+                - Confirmed (int): the number of confirmed cases
+                - Infected (int): the number of currently infected cases
+                - Fatal (int): the number of fatal cases
+                - Recovered (int): the number of recovered cases
+                - any other columns will be ignored
         model (covsirphy.ModelBase): ODE model
         population (int): total population in the place
-        country (str): country name
-        province (str): province name
-        start_date (str): start date, like 22Jan2020
-        end_date (str): end date, like 01Feb2020
-        kwargs: parameter values of the model
+        tau (int): tau value [min], a divisor of 1440
+        kwargs: parameter values of the model and data subseting
     """
     np.seterr(divide="raise")
 
-    def __init__(self, jhu_data, model, population,
-                 country, province=None,
-                 start_date=None, end_date=None, **kwargs):
-        # Check type of model
-        model = self.ensure_subclass(model, ModelBase, name="model")
+    def __init__(self, record_df, model, population, tau=None, **kwargs):
+        # Arguments
+        self.population = self.ensure_population(population)
+        self.model = self.ensure_subclass(model, ModelBase, name="model")
+        self.tau = self.ensure_tau(tau)
         # Dataset
-        if isinstance(jhu_data, pd.DataFrame):
-            warnings.warn(
-                "Please use instance of JHUData as the first argument of Trend class.",
-                DeprecationWarning,
-                stacklevel=2
+        if isinstance(record_df, JHUData):
+            subset_arg_dict = find_args(
+                [JHUData.subset, record_df.subset], **kwargs)
+            self.record_df = record_df.subset(
+                population=population, **subset_arg_dict)
+        else:
+            if not set(self.NLOC_COLUMNS).issubset(record_df.columns):
+                record_df = model.restore(record_df)
+            self.record_df = self.ensure_dataframe(
+                record_df, name="record_df", columns=self.NLOC_COLUMNS
             )
-            df = jhu_data.copy()
-            if not set(self.VALUE_COLUMNS).issubset(set(df.columns)):
-                df = model.restore(df)
-            jhu_data = JHUData.from_dataframe(df)
-        jhu_data = self.ensure_instance(jhu_data, JHUData, name="jhu_data")
-        # Read arguments
-        self.model = model
-        self.population = population
-        self.country = country
-        self.province = province
-        self.start_date = start_date
-        self.end_date = end_date
-        self.fixed_dict = kwargs.copy()
-        if self.TAU in self.fixed_dict.keys():
-            self.fixed_dict[self.TAU] = self.ensure_natural_int(
-                self.fixed_dict[self.TAU], name="tau"
-            )
-        # Training dataset
-        self.subset_df = jhu_data.subset(
-            country=country, province=province,
-            start_date=start_date, end_date=end_date
-        )
-        df = model.tau_free(self.subset_df, population, tau=None)
+        # Initial values
+        df = model.tau_free(self.record_df, population, tau=None)
         self.y0_dict = {
             k: df.loc[df.index[0], k] for k in model.VARIABLES
         }
+        # Fixed parameter values
+        self.fixed_dict = {
+            k: v for (k, v) in kwargs.items()
+            if k in set(model.PARAMETERS) and v is not None
+        }
         # For optimization
         optuna.logging.disable_default_handler()
         self.x = self.TS
@@ -80,22 +75,8 @@ class Estimator(Optimizer):
         # step_n will be defined in divide_minutes()
         self.step_n = None
 
-    def _run_trial(self, timeout_iteration):
-        """
-        Run trial.
-
-        Args:
-            timeout_iteration (int): time-out of one iteration
-        """
-        self.study.optimize(
-            lambda x: self.objective(x),
-            n_jobs=1,
-            timeout=timeout_iteration
-        )
-
     def run(self, timeout=60, reset_n_max=3,
-            timeout_iteration=5, allowance=(0.8, 1.2),
-            seed=0, stdout=True, **kwargs):
+            timeout_iteration=5, allowance=(0.98, 1.02), seed=0, **kwargs):
         """
         Run optimization.
         If the result satisfied the following conditions, optimization ends.
@@ -109,27 +90,24 @@ class Estimator(Optimizer):
             timeout_iteration (int): time-out of one iteration
             allowance (tuple(float, float)): the allowance of the predicted value
             seed (int or None): random seed of hyperparameter optimization
-            stdout (bool): whether show the status of progress or not
+            kwargs: other keyword arguments will be ignored
 
         Notes:
             @n_jobs was obsoleted because this is not effective for Optuna.
         """
-        if "n_jobs" in kwargs.keys():
-            raise KeyError("@n_jobs of Estimator.run() was obsoleted.")
         # Create a study of optuna
         if self.study is None:
             self._init_study(seed=seed)
         reset_n = 0
         iteration_n = math.ceil(timeout / timeout_iteration)
         increasing_cols = [f"{v}{self.P}" for v in self.model.VARS_INCLEASE]
-        if stdout:
-            print("\tRunning optimization...")
         stopwatch = StopWatch()
         for _ in range(iteration_n):
             # Perform optimization
-            self._run_trial(timeout_iteration=timeout_iteration)
+            self.study.optimize(
+                self.objective, n_jobs=1, timeout=timeout_iteration)
             # Create a table to compare observed/estimated values
-            tau = super().param()[self.TAU]
+            tau = self.tau or super().param()[self.TAU]
             train_df = self.divide_minutes(tau)
             comp_df = self.compare(train_df, self.predict())
             # Check monotonic variables
@@ -148,11 +126,8 @@ class Estimator(Optimizer):
                 break
         # Calculate run-time and the number of trials
         self.run_time = stopwatch.stop()
+        self.run_time_show = stopwatch.show()
         self.total_trials = len(self.study.trials)
-        if stdout:
-            print(
-                f"\tFinished {self.total_trials} trials in {stopwatch.show()}.",
-            )
 
     def _is_in_allowance(self, comp_df, allowance):
         """
@@ -187,23 +162,20 @@ class Estimator(Optimizer):
         Returns:
             (float): score of the error function to minimize
         """
-        fixed_dict = self.fixed_dict.copy()
         # Convert T to t using tau
-        if self.TAU in fixed_dict.keys():
-            tau = fixed_dict.pop(self.TAU)
-        else:
+        tau = self.tau
+        if tau is None:
             tau = trial.suggest_categorical(self.TAU, self.tau_candidates)
         taufree_df = self.divide_minutes(tau)
         # Set parameters of the models
         model_param_dict = self.model.param_range(
-            taufree_df, self.population
-        )
+            taufree_df, self.population)
         p_dict = {
             k: trial.suggest_uniform(k, *v)
             for (k, v) in model_param_dict.items()
             if k not in self.fixed_dict.keys()
         }
-        p_dict.update(fixed_dict)
+        p_dict.update(self.fixed_dict)
         return self.error_f(p_dict, taufree_df)
 
     def divide_minutes(self, tau):
@@ -221,7 +193,7 @@ class Estimator(Optimizer):
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensional variables
         """
-        df = self.model.tau_free(self.subset_df, self.population, tau=tau)
+        df = self.model.tau_free(self.record_df, self.population, tau=tau)
         self.step_n = int(df[self.TS].max())
         return df
 
@@ -244,8 +216,6 @@ class Estimator(Optimizer):
         Returns:
             (float): score of the error function to minimize
         """
-        if self.step_n is None:
-            raise ValueError("self.step_n must be defined in advance.")
         sim_df = self.simulate(self.step_n, param_dict)
         df = self.compare(taufree_df, sim_df)
         # Calculate error score
@@ -257,14 +227,13 @@ class Estimator(Optimizer):
         diffs = [df[f"{v}{self.A}"] - df[f"{v}{self.P}"] for v in v_list]
         numerators = [df[f"{v}{self.A}"] + 1 for v in v_list]
         try:
-            score = sum(
+            return sum(
                 p * np.average(diff.abs() / numerator, weights=df.index)
                 for (p, diff, numerator)
                 in zip(self.model.PRIORITIES, diffs, numerators)
             )
         except (ZeroDivisionError, TypeError):
             return np.inf
-        return score
 
     def simulate(self, step_n, param_dict):
         """
@@ -284,7 +253,7 @@ class Estimator(Optimizer):
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensionalized variables
         """
-        simulator = ODESimulator(country=self.country, province=self.province)
+        simulator = ODESimulator()
         simulator.add(
             model=self.model,
             step_n=step_n,
@@ -292,21 +261,19 @@ class Estimator(Optimizer):
             param_dict=param_dict,
             y0_dict=self.y0_dict
         )
-        simulator.run()
         return simulator.taufree()
 
-    def summary(self, name):
+    def to_dict(self):
         """
         Summarize the results of optimization.
-        This function should be overwritten in subclass.
 
         Args:
-            name (str): index of the dataframe
+            name (str or None): index of the dataframe
 
         Returns:
             (pandas.DataFrame):
                 Index:
-                    reset index
+                    name or reset index (when name is None)
                 Columns:
                     - (parameters of the model)
                     - tau
@@ -316,39 +283,58 @@ class Estimator(Optimizer):
                     - Trials: the number of trials
                     - Runtime: run time of estimation
         """
-        param_dict = super().param()
-        model_params = param_dict.copy()
-        tau = model_params.pop(self.TAU)
+        est_dict = super().param()
+        if self.TAU not in est_dict:
+            est_dict[self.TAU] = self.tau
         model_instance = self.model(
-            population=self.population, **model_params
+            population=self.population,
+            **{k: v for (k, v) in est_dict.items() if k != self.TAU}
         )
-        # Rt
-        param_dict["Rt"] = model_instance.calc_r0()
-        # dimensional parameters [day]
-        param_dict.update(model_instance.calc_days_dict(tau))
-        # RMSLE
-        param_dict["RMSLE"] = self.rmsle(tau)
-        # The number of trials
-        param_dict["Trials"] = self.total_trials
-        # Runtime
         minutes, seconds = divmod(int(self.run_time), 60)
-        param_dict["Runtime"] = f"{minutes} min {seconds} sec"
-        # Convert to dataframe
-        df = pd.DataFrame.from_dict({name: param_dict}, orient="index")
+        return {
+            **est_dict,
+            self.RT: model_instance.calc_r0(),
+            **model_instance.calc_days_dict(est_dict[self.TAU]),
+            self.RMSLE: self._rmsle(est_dict[self.TAU]),
+            self.TRIALS: self.total_trials,
+            self.RUNTIME: f"{minutes} min {seconds:>2} sec"
+        }
+
+    def summary(self, name=None):
+        """
+        Summarize the results of optimization.
+
+        Args:
+            name (str or None): index of the dataframe
+
+        Returns:
+            (pandas.DataFrame):
+                Index:
+                    name or reset index (when name is None)
+                Columns:
+                    - (parameters of the model)
+                    - tau
+                    - Rt: basic or phase-dependent reproduction number
+                    - (dimensional parameters [day])
+                    - RMSLE: Root Mean Squared Log Error
+                    - Trials: the number of trials
+                    - Runtime: run time of estimation
+        """
+        summary_dict = {name or 0: self.to_dict()}
+        df = pd.DataFrame.from_dict(summary_dict, orient="index")
         return df.fillna(self.UNKNOWN)
 
-    def rmsle(self, tau):
+    def _rmsle(self, tau):
         """
         Return RMSLE score.
 
         Args:
-            tau (int): tau value
+            tau (int): tau value [min]
         """
-        score = super().rmsle(
+        return super().rmsle(
             train_df=self.divide_minutes(tau),
             dim=1
         )
-        return score
 
     def accuracy(self, show_figure=True, filename=None):
         """
@@ -358,17 +344,18 @@ class Estimator(Optimizer):
             show_figure (bool): if True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
         """
-        tau = super().param()[self.TAU]
-        train_df = self.divide_minutes(tau)
+        est_dict = super().param()
+        if self.TAU not in est_dict:
+            est_dict[self.TAU] = self.tau
+        train_df = self.divide_minutes(est_dict[self.TAU])
         use_variables = [
             v for (i, (p, v))
             in enumerate(zip(self.model.PRIORITIES, self.model.VARIABLES))
             if p != 0 and i != 0
         ]
-        df = super().accuracy(
+        return super().accuracy(
             train_df=train_df,
             variables=use_variables,
             show_figure=show_figure,
             filename=filename
         )
-        return df
